@@ -862,7 +862,7 @@ class UFOOperator(object):
                 self.logger.info(f"\t\t{os.path.basename(instanceDescriptor.path)}")
 
             instanceFolder = os.path.dirname(instanceDescriptor.path)
-            if not os.path.exists(instanceFolder):
+            if instanceFolder and not os.path.exists(instanceFolder):
                 os.makedirs(instanceFolder)
             font.save(instanceDescriptor.path)
             generatedFontPaths.append(instanceDescriptor.path)
@@ -1332,7 +1332,7 @@ class UFOOperator(object):
                 if self.debug:
                     self.logger.info(f"\t\t\tlibMathMutator: libKey \"{libKey}: {mutatedValue}")
 
-        defaultSourceFont = self.findDefaultFont()
+        defaultSourceFont = self.findDefaultFont(discreteLocation=discreteLocation)
         # found a default source font
         if defaultSourceFont:
             # copy info
